PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/gaunt.py File Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

Namespaces | Variables
gaunt.py File Reference

## Namespaces
| pawpyseed.core.gaunt

## Variables
| pawpyseed.core.gaunt.gcs = np.zeros([4,4,4,7,4])
| pawpyseed.core.gaunt.facs = np.zeros([4,4,4,7,4])
| pawpyseed.core.gaunt.val = N(gaunt(l1,l2,l3,m1,m2,-m1-m2))
| pawpyseed.core.gaunt.val2 = N(wigner_3j(l1,l2,l3,0,0,0))*N(wigner_3j(l1,l2,l3,-m1,m2,m1-m2))
| pawpyseed.core.gaunt.val3 = np.sqrt((2*l1+1)*(2*l2+1)*(2*l3+1)/4/np.pi)
| pawpyseed.core.gaunt.f = open('gaunt.c', 'w')